==> tstrait-0.0.1a5.tar.gz: tstrait-0.0.1a5/docs/api.md <==
(reference)=

# API Reference

```{eval-rst}
.. currentmodule:: tstrait
```

This page provides a detailed explanation of all public tstrait objects and functions.

## Summary

### Simulation functions

```{eval-rst}
.. autosummary::

   sim_phenotype
   sim_trait
   sim_genetic
   sim_env
```

(effect_size_distribution)=

### Effect size distributions

```{eval-rst}
.. autosummary::

   trait_model
   TraitModel
   TraitModelNormal
   TraitModelT
   TraitModelFixed
   TraitModelExponential
   TraitModelGamma
   TraitModelMultivariateNormal
```

### Result data classes

```{eval-rst}
.. autosummary::

   PhenotypeResult
   GeneticResult
```

## Reference documentation

### Simulation functions

```{eval-rst}
.. autofunction:: tstrait.sim_phenotype
```

```{eval-rst}
.. autofunction:: tstrait.sim_trait
```

```{eval-rst}
.. autofunction:: tstrait.sim_genetic
```

```{eval-rst}
.. autofunction:: tstrait.sim_env
```

### Effect size distributions

```{eval-rst}
.. autofunction:: tstrait.trait_model
```

```{eval-rst}
.. autoclass:: tstrait.TraitModel
```

```{eval-rst}
.. autoclass:: tstrait.TraitModelNormal
```

```{eval-rst}
.. autoclass:: tstrait.TraitModelT
```

```{eval-rst}
.. autoclass:: tstrait.TraitModelFixed
```

```{eval-rst}
.. autoclass:: tstrait.TraitModelExponential
```

```{eval-rst}
.. autoclass:: tstrait.TraitModelGamma
```

```{eval-rst}
.. autoclass:: tstrait.TraitModelMultivariateNormal
```

### Result data classes

```{eval-rst}
.. autoclass:: tstrait.PhenotypeResult
```

```{eval-rst}
.. autoclass:: tstrait.GeneticResult
```

==> tstrait-0.1.0.tar.gz: tstrait-0.1.0/docs/api.md <==
(reference)=

# API Reference

```{eval-rst}
.. currentmodule:: tstrait
```

This page provides a detailed explanation of all public tstrait objects and functions.

## Summary

### Simulation functions

```{eval-rst}
.. autosummary::

   sim_phenotype
   sim_trait
   genetic_value
   sim_env
```

(effect_size_distribution)=

### Effect size distributions

```{eval-rst}
.. autosummary::

   trait_model
   TraitModel
   TraitModelNormal
   TraitModelT
   TraitModelFixed
   TraitModelExponential
   TraitModelGamma
   TraitModelMultivariateNormal
```

### Postprocessing functions

```{eval-rst}
.. autosummary::

   normalise_phenotypes
   normalise_genetic_value
```

### Result data classes

```{eval-rst}
.. autosummary::

   PhenotypeResult
```

## Reference documentation

### Simulation functions

```{eval-rst}
.. autofunction:: tstrait.sim_phenotype
```

```{eval-rst}
.. autofunction:: tstrait.sim_trait
```

```{eval-rst}
.. autofunction:: tstrait.genetic_value
```

```{eval-rst}
.. autofunction:: tstrait.sim_env
```

### Effect size distributions

```{eval-rst}
.. autofunction:: tstrait.trait_model
```

```{eval-rst}
.. autoclass:: tstrait.TraitModel
```

```{eval-rst}
.. autoclass:: tstrait.TraitModelNormal
```

```{eval-rst}
.. autoclass:: tstrait.TraitModelT
```

```{eval-rst}
.. autoclass:: tstrait.TraitModelFixed
```

```{eval-rst}
.. autoclass:: tstrait.TraitModelExponential
```

```{eval-rst}
.. autoclass:: tstrait.TraitModelGamma
```

```{eval-rst}
.. autoclass:: tstrait.TraitModelMultivariateNormal
```

### Postprocessing functions

```{eval-rst}
.. autofunction:: tstrait.normalise_phenotypes
```

```{eval-rst}
.. autofunction:: tstrait.normalise_genetic_value
```

### Result data classes

```{eval-rst}
.. autoclass:: tstrait.PhenotypeResult
```
